This package was made by a high school student who was frustrated with the performance evaluation that required hand coding, and it was designed to calculate the internal vector of the vector, the eigenvalues of the matrix, the eigenvectors, the inverse matrix, and the diagonal matrix. Please use it well.

Pleas contact me at : minjaepark3837@gmail.com